@@ -6,4 +6,6 @@ import enum
 
 
 class TagValues(str, enum.Enum):
+    BIND = "bind"
     CHALLENGE = "challenge"
+    PROFILE = "profile"
