@@ -10,6 +10,8 @@ class PathValues(str, enum.Enum):
     CHALLENGE_VERIFY_EVM = "/challenge/verify/evm"
     CHALLENGE_REQUEST_SOLANA = "/challenge/request/solana"
     CHALLENGE_VERIFY_SOLANA = "/challenge/verify/solana"
+    CHALLENGE_REQUEST_APTOS = "/challenge/request/aptos"
+    CHALLENGE_VERIFY_APTOS = "/challenge/verify/aptos"
     PROFILE_PROFILE_ID_ADDRESSES = "/profile/{profileId}/addresses"
     BIND_REQUEST = "/bind/request"
     BIND_REQUEST_VERIFY = "/bind/request/verify"
